@@ -104,7 +104,6 @@ static const char sccsid[] = "@(#)fire.c	5.02 2001/09/26 xlockmore";
 #define MINSIZE 32
 
 #include <GL/gl.h>
-#include <GL/glx.h>
 #include <GL/glu.h>
 
 #ifdef HAVE_XPM
@@ -288,8 +287,12 @@ typedef struct {
 
 /* the mode struct, contains all per screen variables */
 typedef struct {
-    GLint WIDTH, HEIGHT;	/* display dimensions */
+#ifdef WIN32
+    HGLRC glx_context;
+#else
     GLXContext *glx_context;
+#endif
+    GLint WIDTH, HEIGHT;	/* display dimensions */
 
     int np;			/* number of fire particles : set it through 'count' resource */
     float eject_r;		/* emission radius */
@@ -331,6 +334,9 @@ static firestruct *fire = (firestruct *) NULL;
  *-----------------------------------------------------------------------------
  */
 
+#ifdef WIN32
+#include <time.h>
+#endif
 /* utility function for the rain particles */
 static float gettimerain(void)
 {
@@ -663,11 +669,7 @@ static Bool inittree(ModeInfo * mi)
  *-----------------------------------------------------------------------------
  */
 
-#ifndef STANDALONE
-static void Reshape(ModeInfo * mi)
-#else
 void reshape_fire(ModeInfo * mi, int width, int height)
-#endif
 {
 
     firestruct *fs = &fire[MI_SCREEN(mi)];
@@ -675,16 +677,16 @@ void reshape_fire(ModeInfo * mi, int width, int height)
 
     /* Viewport is specified size if size >= MINSIZE && size < screensize */
     if (size <= 1) {
-        fs->WIDTH = MI_WIDTH(mi);
-        fs->HEIGHT = MI_HEIGHT(mi);
+        fs->WIDTH = width;
+        fs->HEIGHT = height;
     } else if (size < MINSIZE) {
         fs->WIDTH = MINSIZE;
         fs->HEIGHT = MINSIZE;
     } else {
-        fs->WIDTH = (size > MI_WIDTH(mi)) ? MI_WIDTH(mi) : size;
-        fs->HEIGHT = (size > MI_HEIGHT(mi)) ? MI_HEIGHT(mi) : size;
+        fs->WIDTH = (size > width) ? width : size;
+        fs->HEIGHT = (size > height) ? height : size;
     }
-    glViewport((MI_WIDTH(mi) - fs->WIDTH) / 2, (MI_HEIGHT(mi) - fs->HEIGHT) / 2, fs->WIDTH, fs->HEIGHT);
+    glViewport((width - fs->WIDTH) / 2, (height - fs->HEIGHT) / 2, fs->WIDTH, fs->HEIGHT);
     glMatrixMode(GL_PROJECTION);
     glLoadIdentity();
     gluPerspective(70.0, fs->WIDTH / (float) fs->HEIGHT, 0.1, 30.0);
@@ -741,13 +743,13 @@ static void DrawFire(ModeInfo * mi)
     glEnable(GL_TEXTURE_2D);
 
     /* draw ground using the computed texture */
+#ifdef HAVE_GLBINDTEXTURE
     if (do_texture) {
 	glColor4f(1.0,1.0,1.0,1.0);	/* white to get texture in it's true color */
-#ifdef HAVE_GLBINDTEXTURE
 	glBindTexture(GL_TEXTURE_2D, fs->groundid);
-#endif /* HAVE_GLBINDTEXTURE */
     }
     else
+#endif /* HAVE_GLBINDTEXTURE */
         glColor4f(0.54, 0.27, 0.07, 1.0);	/* untextured ground color */
     glBegin(GL_QUADS);
     glTexCoord2fv(qt[0]);
@@ -761,17 +763,17 @@ static void DrawFire(ModeInfo * mi)
     glEnd();
 
     glAlphaFunc(GL_GEQUAL, 0.9);
+#ifdef HAVE_GLBINDTEXTURE
     if (fs->num_trees)
     {
 	/* here do_texture IS True - and color used is white */
 	glEnable(GL_ALPHA_TEST);
-#ifdef HAVE_GLBINDTEXTURE
 	glBindTexture(GL_TEXTURE_2D,fs->treeid);
-#endif /* HAVE_GLBINDTEXTURE */
 	for(j=0;j<fs->num_trees;j++)
 	    drawtree(fs->treepos[j].x ,fs->treepos[j].y ,fs->treepos[j].z );
     	glDisable(GL_ALPHA_TEST);
     }
+#endif /* HAVE_GLBINDTEXTURE */
     glDisable(GL_TEXTURE_2D);
     glDepthMask(GL_FALSE);
 
@@ -1005,11 +1007,7 @@ init_fire(ModeInfo * mi)
     /* xlock GL stuff */
     if ((fs->glx_context = init_GL(mi)) != NULL) {
 
-#ifndef STANDALONE
-	Reshape(mi); /* xlock mode */
-#else
-	reshape_fire(mi,MI_WIDTH(mi),MI_HEIGHT(mi)); /* xscreensaver mode */
-#endif
+	reshape_fire(mi,MI_WIDTH(mi),MI_HEIGHT(mi));
 	glDrawBuffer(GL_BACK);
 	if (!Init(mi)) {
 		free_fire(fs);
@@ -1036,15 +1034,13 @@ void draw_fire(ModeInfo * mi)
 
     if (!fs->glx_context)
 	return;
-
-    glXMakeCurrent(display, window, *(fs->glx_context));
-    DrawFire(mi);
-#ifndef STANDALONE
-    Reshape(mi); /* xlock mode */
+#ifdef WIN32
+    wglMakeCurrent(hdc, fs->glx_context);
 #else
-    reshape_fire(mi,MI_WIDTH(mi),MI_HEIGHT(mi)); /* xscreensaver mode */
+    glXMakeCurrent(display, window, *(fs->glx_context));
 #endif
-
+    DrawFire(mi);
+    reshape_fire(mi,MI_WIDTH(mi),MI_HEIGHT(mi));
     glFinish();
     glXSwapBuffers(display, window);
 }
@@ -1083,8 +1079,11 @@ void change_fire(ModeInfo * mi)
     if (!fs->glx_context)
 	return;
 
+#ifdef WIN32
+    wglMakeCurrent(hdc, fs->glx_context);
+#else
     glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(fs->glx_context));
-
+#endif
     /* if available, randomly change some values */
     if (do_fog)
 	fs->fog = LRAND() & 1;
