@@ -549,8 +549,7 @@ match_rules(fringe_node_c * vertex, rule_match_c * matches, int first_only)
 	   congruence arithmetic. */
 	register int i, j;
 	int         hits = 0, good_rules[N_VERTEX_RULES], n_good = 0;
-	unsigned long
-	            vertex_hash = 0, lower_bits_mask = ~((VT_TOTAL_MASK << VT_BITS) * (vertex->n_tiles - 1));
+	unsigned long vertex_hash = 0, lower_bits_mask = ~(VT_TOTAL_MASK << VT_BITS * (vertex->n_tiles - 1));
 	unsigned    new_rule_mask = 0;
 
 	for (i = 0; i < N_VERTEX_RULES; i++)
