@@ -84,9 +84,9 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-	{(caddr_t *) & invert, "invert", "Invert", DEF_INVERT, t_Bool},
-	{(caddr_t *) &modparam_msg, "msg", "Msg", "", t_String	},
-	{(caddr_t *) &modparam_fnt, "fnt", "Fnt", DEFAULT_FNT, t_String	}
+	{(void *) &invert, "invert", "Invert", DEF_INVERT, t_Bool},
+	{(void *) &modparam_msg, "msg", "Msg", "", t_String	},
+	{(void *) &modparam_fnt, "fnt", "Fnt", DEFAULT_FNT, t_String	}
 };
 
 static OptionStruct desc[] = {
@@ -190,7 +190,6 @@ static char * ostext = NULL;
 
 static int rbits, gbits, bbits;
 static int rpos, gpos, bpos;
-static int rmask,  gmask, bmask;
 
 typedef struct para {
 	int init;	/* == true : initialization needed */
@@ -250,11 +249,12 @@ typedef struct	{
 	XImage *image;
 } LOGO_BITMAP;
 
+#define TEXT_LEN 256
 typedef struct pyro {
 	int stat;	/* status der rakette: parabell, explosion, fertig */
 	int wait;	/* warten bevor start */
 	int textlen;
-	char text[256];
+	char text[TEXT_LEN];
 	LOGO_BITMAP *bitmap;
 	unsigned int etype;
 	PARA para;
@@ -273,61 +273,6 @@ typedef struct {
 	int		nsteps;
 } pyrostruct;
 
-#if NOT_YET
-typedef enum {
-	EXP_TYPE_0, EXP_TYPE_1, EXP_TYPE_2, EXP_TYPE_3, EXP_TYPE_4, EXP_TYPE_5,
-	EXP_TYPE_6, EXP_TYPE_7, EXP_TYPE_8, EXP_TYPE_9, EXP_TYPE_A, EXP_TYPE_B,
-	EXP_TYPE_C, EXP_TYPE_D, EXP_TYPE_E, EXP_TYPE_F, EXP_TYPE_G, EXP_TYPE_H,
-	EXP_TYPE_I, EXP_TYPE_J, EXP_TYPE_K, EXP_TYPE_L, EXP_TYPE_M, EXP_TYPE_N,
-	EXP_TYPE_O, EXP_TYPE_P, EXP_TYPE_Q, EXP_TYPE_R, EXP_TYPE_S, EXP_TYPE_T,
-	EXP_TYPE_U, EXP_TYPE_V, EXP_TYPE_W, EXP_TYPE_X, EXP_TYPE_Y, EXP_TYPE_Z,
-	EXP_TYPE_LOGO, EXP_TYPE_TEXT
-} EXPLOSION_TYPE;
-
-typedef struct stage	{
-	int init;
-	int x0, y0;
-	double time;	/* time since explosion for each spark :-) */
-	double v0;	/* initial speed of each spark */
-	double delta_t;/* value to be added to the time in each iteration for each spark */
-	double phi;	/* angle of the each spark as it leaves the explosion center */
-	double m;	/* */
-	int generation;/* the generation of each spark */
-	int x1, y1;
-	int x2, y2;
-	int ttl;	/* time to leave of each spark (max = EXP_MAX_TTL) */
-	int current_generation;/* current generation of sparks */
-	unsigned int type;	/* type of spark */
-	int *color;
-}STAGE;
-
-typedef struct missile	{
-	int stage;	/* firework stage: ST_PARABOLA, ST_EXPLOSION, ST_DEAD */
-	int start_time;
-	int color1, color2; /* startcolor, index in colors */
-	char msg[256];
-	EXPLOSION_TYPE etype;
-	struct missle *next;
-} MISSILE;
-
-
-/*
- * for each screen an instance of FIREWORKS
- * will be allocated.
- */
-typedef struct {
-	GC		*gc;
-	Colormap	cmap;
-	XColor		*colors;
-	int		ncolors;
-	unsigned long	blackpixel, whitepixel, fg, bg, love;
-	int		nhues, nsteps;
-	int		*missile_count;
-
-} FIREWORKS;
-#endif /* #if NOT_YET */
-
-
 static void parabel(ModeInfo * mi, PYRO *p);
 static void explosion(ModeInfo * mi, PYRO *p);
 static int calc(ModeInfo * mi, PYRO *p);
@@ -366,13 +311,13 @@ static int calc(ModeInfo * mi, PYRO *pyro)
 				if(--pyro[i].wait <= 0) {
 					pyro[i].stat = PARABEL;
 				}
-				else
-					delay(1);
+				/*else
+					delay(1);*/
 				break;
 			case PARABEL:
 				ret = 1;
 				parabel(mi, &pyro[i]);
-				delay(1);
+				/*delay(1);*/
 				break;
 			case EXPLOSION:
 				ret = 1;
@@ -381,7 +326,7 @@ static int calc(ModeInfo * mi, PYRO *pyro)
 			default:
 				pyro[i].stat = READY;
 				free_pyro(&pyro[i]);
-				delay(1);
+				/*delay(1);*/
 		}
 
 
@@ -562,7 +507,6 @@ static void explosion(ModeInfo * mi, PYRO *p)
 	int i, sparks;
 	int sumttl;
 	static int num = 0;
-	int multicol;
 
 	double v0, dt, t;
 
@@ -736,7 +680,7 @@ static void explosion(ModeInfo * mi, PYRO *p)
 				}
 			break;
 			case 5:	{
-				double tmp = (double)e->current_generation/(double)EXP_MAX_GENERATION;
+				/*double tmp = (double)e->current_generation/(double)EXP_MAX_GENERATION;*/
 				e->v0[e->sparkcnt] = Rand(30)+COS((int)((double)e->current_generation/(double)EXP_MAX_GENERATION *360.0) % 90) * COS((double)e->current_generation/(double)EXP_MAX_GENERATION *360.0) * MI_WIDTH(mi)/5 * factor;
 			}
 			break;
@@ -746,7 +690,7 @@ static void explosion(ModeInfo * mi, PYRO *p)
 			}
 			break;
 			case 7:	{
-				double tmp = (double)e->current_generation/(double)EXP_MAX_GENERATION;
+				/*double tmp = (double)e->current_generation/(double)EXP_MAX_GENERATION;*/
 				e->v0[e->sparkcnt] = Rand(30)+((i-sparks/2)*SIN(phi*10)*SIN((int)((double)e->current_generation/(EXP_MAX_GENERATION)*360.0)%90))*MI_WIDTH(mi)/50 * factor;
 			}
 			break;
@@ -772,13 +716,13 @@ static void explosion(ModeInfo * mi, PYRO *p)
 				break;
 			}
 			case 13:	{
-				double tmp = (double)e->current_generation/(double)EXP_MAX_GENERATION;
+				/*double tmp = (double)e->current_generation/(double)EXP_MAX_GENERATION;*/
 				e->v0[e->sparkcnt] = Rand(2)? i * 20:(sparks-i)*20;
 				break;
 
 			}
 			case 14:	{
-				double tmp = (double)e->current_generation/(double)EXP_MAX_GENERATION;
+				/*double tmp = (double)e->current_generation/(double)EXP_MAX_GENERATION;*/
 				e->v0[e->sparkcnt] = 5+ (Rand(20) == 3? i:(sparks-i))*20;
 				break;
 
@@ -1004,150 +948,6 @@ static LOGO_BITMAP *text2bitmap(ModeInfo *mi, char *text)
 }
 #endif
 
-#if NOT_YET
-static PYRO *parse_msg(ModeInfo *mi, char *msg)
-{
-	int pyrocnt = 0, text_in_buffer = FALSE, i;
-	PYRO *pyro = NULL;
-	char *rov = msg;
-
-	while(*rov)	{
-		switch(*rov)	{
-			case '&':		/* internal explosion type */
-				rov += 2;
-				if(text_in_buffer == TRUE)	++pyrocnt;
-				text_in_buffer = FALSE;
-				++pyrocnt;
-				break;
-			case '#':
-				++rov;
-				if(text_in_buffer == TRUE)	++pyrocnt;
-				text_in_buffer = FALSE;
-				++pyrocnt;
-				break;
-			case ' ':
-				++rov;
-				break;
-			default:
-
-				if(*rov == ' ' && text_in_buffer == FALSE)	break;
-
-				if(*rov == '\\')
-					switch(rov[1])	{
-						case '&':
-						case '\\':
-						case '#':
-						case ' ':
-							++rov;
-							break;
-						default:
-							break;
-				}
-				text_in_buffer = TRUE;
-				++rov;
-			break;
-		}
-	}
-
-	if(text_in_buffer)	++pyrocnt;
-
-	pyro = calloc(pyrocnt, sizeof(PYRO));
-	rov = msg;
-	text_in_buffer = FALSE;
-	i = 0;
-
-	while(*rov)	{
-		switch(*rov)	{
-			case '&':	{
-				static char buf[8];
-				int type = 0;
-				if(text_in_buffer == TRUE)	++i;
-				text_in_buffer = FALSE;
-
-				memset(buf, 0, sizeof(buf));
-				++rov;
-				*buf = *rov++;
-				if(*buf >= '0' && *buf <= '9')	type = *buf - '0';
-				if(*buf >= 'a' && *buf <= 'z')	type = *buf - 'a' + 10;
-				if(*buf >= 'A' && *buf <= 'Z')	type = *buf - 'A' + 10;
-				pyro[i].etype = type;
-				++i;
-			}
-			break;
-#ifdef WIN32
-			case '#':	{	/* logo */
-				XImage *image;
-				int graphics_format;
-				Colormap cmap;
-				unsigned long black;
-				LOGO_BITMAP *bitmap;
-
-				if(text_in_buffer == TRUE)	++i;
-				text_in_buffer = FALSE;
-
-				getImage(mi, &image, LOGO_WIDTH, LOGO_HEIGHT, LOGO_BITS,
-#ifdef HAVE_XPM
-				DEFAULT_XPM, LOGO_NAME,
-#endif
-				&graphics_format, &cmap, &black);
-				bitmap = calloc(1, sizeof(LOGO_BITMAP));
-				XImage2bitmap(image, bitmap, 0);
-				pyro[i].bitmap = bitmap;
-				pyro[i].etype = 23;
-				++i;
-				++rov;
-
-				break;
-			}
-#endif
-			default:	{
-				uint32 charcode = 0;
-
-				if(*rov == ' ' && text_in_buffer == FALSE)	{
-					++rov;
-					break;
-				}
-
-				if(*rov == '\\')
-					switch(rov[1])	{
-						case '&':
-						case '\\':
-						case ' ':
-							++rov;
-							break;
-						case 'n':
-							++rov;
-							++rov;
-							charcode = '\n';
-							break;
-						default:
-							break;
-					}
-
-				if(!charcode)	charcode = ((unsigned char)*rov++) & 0xFF;
-				pyro[i].text[pyro[i].textlen++] = charcode;
-				pyro[i].etype = 42;
-				text_in_buffer = TRUE;
-			}
-			break;
-		}
-	}
-
-	for(i=0;i<pyrocnt;++i)	{
-#ifndef WIN32
-		if(pyro[i].textlen)	pyro[i].bitmap = text2bitmap(mi, pyro[i].text);
-#endif
-		pyro[i].stat = WAIT;
-		pyro[i].wait = i * 40;
-
-		pyro[i].color1 = NRAND(PYRO_NHUES)*PYRO_NSHADES; /* offset into pp->colors */
-		pyro[i].color2 = getenv("MULTICOL") ? NRAND(PYRO_NHUES)*PYRO_NSHADES : -1; /* offset into pp->colors */
-	}
-
-	return pyro;
-}
-#endif /* #if NOT_YET */
-
 #ifndef STANDALONE
 	extern char *background;
 	extern char *foreground;
@@ -1157,17 +957,14 @@ void init_pyro2(ModeInfo * mi)
 {
 	int i;
 	time_t t = time(NULL);
-	uint32 charcode;
-	static int t1lib_init_done = FALSE;
 	int text_in_buffer = FALSE;
 	char *rov;
-	int pause = 0;
-	static char defaultString[] =
+	/*static char defaultString[] =
 #if __VMS
 	"&0&1&2&3&4&5&6&7&8&9&a&b OpenVMS &a&b";
 #else
 	"&0&1&2&3&4&5&6&7&8&9&a&b Unix &a&b";
-#endif
+#endif*/
 	Display *display = MI_DISPLAY(mi);
 	Window  window = MI_WINDOW(mi);
 
@@ -1176,14 +973,6 @@ void init_pyro2(ModeInfo * mi)
 	if(pyros == NULL && (pyros = calloc(MI_NUM_SCREENS(mi), sizeof (pyrostruct))) == NULL)
 			return;
 
-#if NOT_YET
-	if(pyrocnt == NULL && (pyrocnt = calloc(MI_NUM_SCREENS(mi), sizeof(int))) == NULL)
-		return;
-
-	if(pyro == NULL && (pyro = calloc(MI_NUM_SCREENS(mi), sizeof(PYRO))) == NULL)
-		return;
-#endif /* #if NOT_YET */
-
         if (messagefont == None && !(messagefont = XLoadQueryFont(display, modparam_fnt)))	{
 		fprintf(stderr, "can not find font '%s'\n", modparam_fnt);
 		release_pyro2(mi);
@@ -1195,7 +984,7 @@ void init_pyro2(ModeInfo * mi)
 	if(!pp->gc) {
 		if(MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
 			XColor      color;
-			int i, hue, ncol;
+			int hue, ncol;
 
 #ifndef STANDALONE
 			pp->fg = MI_FG_PIXEL(mi);
@@ -1247,7 +1036,6 @@ void init_pyro2(ModeInfo * mi)
 
 			for(hue=0; hue < PYRO_NHUES ; ++hue ) {
 				int h;
-				double s,b;
 
 				h = hue ? (360/(PYRO_NHUES-1)) * (hue-1) : 0;
 
@@ -1330,17 +1118,6 @@ void init_pyro2(ModeInfo * mi)
 		}
 	}
 #endif
-#if NOT_YET
-	if (!modparam_msg || !*modparam_msg) {
-		if (ostext == NULL)
-			pyro = parse_msg(mi, DEFAULT_MSG);
-		} else
-			pyro = parse_msg(mi, ostext);
-		}
-	} else
-		pyro = parse_msg(mi, modparam_msg);
-
-#else /* #if NOT_YET */
 	if (!modparam_msg || !*modparam_msg) {
 		if (ostext == NULL)
 			rov = DEFAULT_MSG;
@@ -1371,6 +1148,7 @@ void init_pyro2(ModeInfo * mi)
 			default:
 
 				if(*rov == ' ' && text_in_buffer == FALSE)
+					/*++rov;*/
 					break;
 
 				if(*rov == '\\')
@@ -1467,11 +1245,17 @@ void init_pyro2(ModeInfo * mi)
 							charcode = '\n';
 							break;
 						default:
+							/*++rov;*/
 							break;
 					}
 
-				if(!charcode)	charcode = ((unsigned char)*rov++) & 0xFF;
-				pyro[i].text[pyro[i].textlen++] = charcode;
+				if(!charcode)
+					charcode = ((unsigned char)*rov++) & 0xFF;
+				/*if (pyro[i].textlen >= TEXT_LEN - 1)
+					pyro[i].textlen = 0;
+				else*/
+					pyro[i].textlen++;
+				pyro[i].text[pyro[i].textlen] = charcode;
 				pyro[i].etype = 42;
 				text_in_buffer = TRUE;
 			}
@@ -1481,7 +1265,8 @@ void init_pyro2(ModeInfo * mi)
 
 	for(i=0;i<pyrocnt;++i)	{
 #ifndef WIN32
-		if(pyro[i].textlen)	pyro[i].bitmap = text2bitmap(mi, pyro[i].text);
+		if(pyro[i].textlen)
+			pyro[i].bitmap = text2bitmap(mi, pyro[i].text);
 #endif
 
 		pyro[i].stat = WAIT;
@@ -1490,7 +1275,6 @@ void init_pyro2(ModeInfo * mi)
 		pyro[i].color1 = NRAND(PYRO_NHUES)*PYRO_NSHADES; /* offset into pp->colors */
 		pyro[i].color2 = getenv("MULTICOL") ? NRAND(PYRO_NHUES)*PYRO_NSHADES : -1; /* offset into pp->colors */
 	}
-#endif /* #if NOT_YET #else */
 
 	return;
 }
@@ -1508,9 +1292,9 @@ void draw_pyro2(ModeInfo * mi)
 
 	if(getenv("COLTEST")) {
 #if defined(DEBUG)
-		fprintf(stderr, "red   = %08X\n", MI_RED_MASK(mi));
-		fprintf(stderr, "green = %08X\n", MI_GREEN_MASK(mi));
-		fprintf(stderr, "blue  = %08X\n", MI_BLUE_MASK(mi));
+		fprintf(stderr, "red   = %08lX\n", MI_RED_MASK(mi));
+		fprintf(stderr, "green = %08lX\n", MI_GREEN_MASK(mi));
+		fprintf(stderr, "blue  = %08lX\n", MI_BLUE_MASK(mi));
 #endif /* defined(DEBUG) */
 
 		for(i=0;i<MI_WIDTH(mi);++i)	{
