@@ -2,7 +2,7 @@
 /* wator --- Dewdney's Wa-Tor, water torus simulation */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)wator.c	5.00 2000/11/01 xlockmore";
+static const char sccsid[] = "@(#)wator.c	5.24 2007/01/18 xlockmore";
 
 #endif
 
@@ -22,6 +22,7 @@ static const char sccsid[] = "@(#)wator.c	5.00 2000/11/01 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 18-Jan-2007: Added vertical option.
  * 01-Nov-2000: Allocation checks
  * 10-May-1997: Compatible with xscreensaver
  * 29-Aug-1995: Efficiency improvements.
@@ -54,23 +55,28 @@ static const char sccsid[] = "@(#)wator.c	5.00 2000/11/01 xlockmore";
  * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
  */
 #define DEF_NEIGHBORS  "0"      /* choose random value */
+#define DEF_VERTICAL "False"
 
 static int  neighbors;
+static Bool vertical;
 
 static XrmOptionDescRec opts[] =
 {
-	{(char *) "-neighbors", (char *) ".wator.neighbors", XrmoptionSepArg, (caddr_t) NULL}
+	{(char *) "-neighbors", (char *) ".wator.neighbors", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-vertical", (char *) ".wator.vertical", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+vertical", (char *) ".wator.vertical", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int
-}
+	{(void *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
+	{(void *) & vertical, (char *) "vertical", (char *) "Vertical", (char *) DEF_VERTICAL, t_Bool}
 };
 
 static OptionStruct desc[] =
 {
-	{(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"}
+	{(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"},
+	{(char *) "-/+vertical", (char *) "change orientation for hexagons and triangles"}
 };
 
 ModeSpecOpt wator_opts =
@@ -123,14 +129,14 @@ static XImage logo[BITMAPS] =
 	{0, 0, 0, XYBitmap, (char *) fish5_bits, LSBFirst, 8, LSBFirst, 8, 1},
 	{0, 0, 0, XYBitmap, (char *) fish6_bits, LSBFirst, 8, LSBFirst, 8, 1},
 	{0, 0, 0, XYBitmap, (char *) fish7_bits, LSBFirst, 8, LSBFirst, 8, 1},
-      {0, 0, 0, XYBitmap, (char *) shark0_bits, LSBFirst, 8, LSBFirst, 8, 1},
-      {0, 0, 0, XYBitmap, (char *) shark1_bits, LSBFirst, 8, LSBFirst, 8, 1},
-      {0, 0, 0, XYBitmap, (char *) shark2_bits, LSBFirst, 8, LSBFirst, 8, 1},
-      {0, 0, 0, XYBitmap, (char *) shark3_bits, LSBFirst, 8, LSBFirst, 8, 1},
-      {0, 0, 0, XYBitmap, (char *) shark4_bits, LSBFirst, 8, LSBFirst, 8, 1},
-      {0, 0, 0, XYBitmap, (char *) shark5_bits, LSBFirst, 8, LSBFirst, 8, 1},
-      {0, 0, 0, XYBitmap, (char *) shark6_bits, LSBFirst, 8, LSBFirst, 8, 1},
-      {0, 0, 0, XYBitmap, (char *) shark7_bits, LSBFirst, 8, LSBFirst, 8, 1},
+	{0, 0, 0, XYBitmap, (char *) shark0_bits, LSBFirst, 8, LSBFirst, 8, 1},
+	{0, 0, 0, XYBitmap, (char *) shark1_bits, LSBFirst, 8, LSBFirst, 8, 1},
+	{0, 0, 0, XYBitmap, (char *) shark2_bits, LSBFirst, 8, LSBFirst, 8, 1},
+	{0, 0, 0, XYBitmap, (char *) shark3_bits, LSBFirst, 8, LSBFirst, 8, 1},
+	{0, 0, 0, XYBitmap, (char *) shark4_bits, LSBFirst, 8, LSBFirst, 8, 1},
+	{0, 0, 0, XYBitmap, (char *) shark5_bits, LSBFirst, 8, LSBFirst, 8, 1},
+	{0, 0, 0, XYBitmap, (char *) shark6_bits, LSBFirst, 8, LSBFirst, 8, 1},
+	{0, 0, 0, XYBitmap, (char *) shark7_bits, LSBFirst, 8, LSBFirst, 8, 1},
 };
 
 /* Fish and shark data */
@@ -147,7 +153,7 @@ typedef struct _CellList {
 } CellList;
 
 typedef struct {
-	Bool        painted;
+	Bool        painted, vertical;
 	int         nkind[KINDS];	/* Number of fish and sharks */
 	int         breed[KINDS];	/* Breeding time of fish and sharks */
 	int         sstarve;	/* Time the sharks starve if they dont find a fish */
@@ -207,7 +213,7 @@ drawshape(ModeInfo * mi, int x, int y, int sizex, int sizey,
 
 static void
 drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
-	 Bool alive)
+		Bool alive)
 {
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
@@ -223,81 +229,145 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 		colour = MI_WHITE_PIXEL(mi);
 	XSetForeground(display, gc, colour);
 	if (wp->neighbors == 6) {
-		int         ccol = 2 * col + !(row & 1), crow = 2 * row;
+		int ccol = 2 * col + !(row & 1), crow = 2 * row;
 
-		wp->shape.hexagon[0].x = wp->xb + ccol * wp->xs;
-		wp->shape.hexagon[0].y = wp->yb + crow * wp->ys;
+		if (wp->vertical) {
+			wp->shape.hexagon[0].x = wp->xb + ccol * wp->xs;
+			wp->shape.hexagon[0].y = wp->yb + crow * wp->ys;
+		} else {
+			wp->shape.hexagon[0].y = wp->xb + ccol * wp->xs;
+			wp->shape.hexagon[0].x = wp->yb + crow * wp->ys;
+		}
 		if (wp->xs == 1 && wp->ys == 1)
 			XDrawPoint(display, window, gc,
-			wp->shape.hexagon[0].x, wp->shape.hexagon[0].y);
+				wp->shape.hexagon[0].x,
+				wp->shape.hexagon[0].y);
 		else if (bitmap >= KINDBITMAPS || !alive)
 			XFillPolygon(display, window, gc,
-			    wp->shape.hexagon, 6, Convex, CoordModePrevious);
+				wp->shape.hexagon, 6,
+				Convex, CoordModePrevious);
 		else {
+			int ix = 0, iy = 0, sx, sy;
+
 			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 			XFillPolygon(display, window, gc,
-			    wp->shape.hexagon, 6, Convex, CoordModePrevious);
+				wp->shape.hexagon, 6,
+				Convex, CoordModePrevious);
 			XSetForeground(display, gc, colour);
+			if (wp->vertical) {
+				wp->shape.hexagon[0].x -= wp->xs;
+				wp->shape.hexagon[0].y += wp->ys / 4;
+                                sx = 2 * wp->xs - 6;
+                                sy = 2 * wp->ys - 2;
+				if (wp->xs <= 6 || wp->ys <= 2) {
+					ix = 3;
+					iy = 1;
+				} else
+					ix = 5;
+			} else {
+				wp->shape.hexagon[0].y -= wp->xs;
+				wp->shape.hexagon[0].x += wp->ys / 4;
+                                sy = 2 * wp->xs - 6;
+                                sx = 2 * wp->ys - 2;
+				if (wp->xs <= 6 || wp->ys <= 2) {
+					iy = 3;
+					ix = 1;
+				} else
+					iy = 5;
+			}
 			if (wp->xs <= 6 || wp->ys <= 2)
 				XFillRectangle(display, window, gc,
-				     wp->shape.hexagon[0].x - 3 * wp->xs / 4,
-				     wp->shape.hexagon[0].y + wp->ys / 4, wp->xs, wp->ys);
+					wp->shape.hexagon[0].x + ix,
+					wp->shape.hexagon[0].y + iy,
+					wp->xs, wp->ys);
 			else
 				XFillArc(display, window, gc,
-				     wp->xb + wp->xs * ccol - 3 * wp->xs / 4,
-					 wp->yb + wp->ys * crow + wp->ys / 4,
-					 2 * wp->xs - 6, 2 * wp->ys - 2,
-					 0, 23040);
+					wp->shape.hexagon[0].x + ix, 
+					wp->shape.hexagon[0].y + iy,
+					sy, sy,
+					0, 23040);
 		}
 	} else if (wp->neighbors == 4 || wp->neighbors == 8) {
 		if (wp->pixelmode) {
 			if (bitmap >= KINDBITMAPS || (wp->xs <= 2 || wp->ys <= 2) || !alive)
 				XFillRectangle(display, window, gc,
-				wp->xb + wp->xs * col, wp->yb + wp->ys * row,
-				wp->xs - (wp->xs > 3), wp->ys - (wp->ys > 3));
+					wp->xb + wp->xs * col,
+					wp->yb + wp->ys * row,
+					wp->xs - (wp->xs > 3),
+					wp->ys - (wp->ys > 3));
 			else {
 				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 				XFillRectangle(display, window, gc,
-				wp->xb + wp->xs * col, wp->yb + wp->ys * row,
-					       wp->xs, wp->ys);
+					wp->xb + wp->xs * col,
+					wp->yb + wp->ys * row,
+					wp->xs, wp->ys);
 				XSetForeground(display, gc, colour);
 				XFillArc(display, window, gc,
-					 wp->xb + wp->xs * col, wp->yb + wp->ys * row,
-					 wp->xs - 1, wp->ys - 1,
-					 0, 23040);
+					wp->xb + wp->xs * col,
+					wp->yb + wp->ys * row,
+					wp->xs - 1, wp->ys - 1,
+					0, 23040);
 			}
 		} else
 			(void) XPutImage(display, window, gc,
-					 &logo[bitmap], 0, 0,
+				&logo[bitmap], 0, 0,
 				wp->xb + wp->xs * col, wp->yb + wp->ys * row,
-					 icon_width, icon_height);
-	} else {		/* TRI */
-		int         orient = (col + row) % 2;	/* O left 1 right */
+				icon_width, icon_height);
+	} else { /* TRI */
+		int orient = (col + row) % 2;	/* O left 1 right */
+		Bool small = (wp->xs <= 3 || wp->ys <= 3);
+		int ix = 0, iy = 0;
 
-		wp->shape.triangle[orient][0].x = wp->xb + col * wp->xs;
-		wp->shape.triangle[orient][0].y = wp->yb + row * wp->ys;
-		if (wp->xs <= 3 || wp->ys <= 3)
-			XDrawPoint(display, window, gc,
-			((orient) ? -1 : 1) + wp->shape.triangle[orient][0].x,
-				       wp->shape.triangle[orient][0].y);
-		else {
-			if (orient)
-				wp->shape.triangle[orient][0].x += (wp->xs / 2 - 1);
+		if (wp->vertical) {
+			wp->shape.triangle[orient][0].x = wp->xb + col * wp->xs;
+			wp->shape.triangle[orient][0].y = wp->yb + row * wp->ys;
+			if (small)
+				wp->shape.triangle[orient][0].x +=
+					((orient) ? -1 : 1);
 			else
-				wp->shape.triangle[orient][0].x -= (wp->xs / 2 - 1);
+				wp->shape.triangle[orient][0].x +=
+					(wp->xs / 2  - 1) * ((orient) ? 1 : -1);
+		} else {
+			wp->shape.triangle[orient][0].y = wp->xb + col * wp->xs;
+			wp->shape.triangle[orient][0].x = wp->yb + row * wp->ys;
+			if (small)
+				wp->shape.triangle[orient][0].y +=
+					((orient) ? -1 : 1);
+			else
+				wp->shape.triangle[orient][0].y +=
+					(wp->xs / 2  - 1) * ((orient) ? 1 : -1);
+		}
+		if (small)
+			XDrawPoint(display, window, gc,
+				wp->shape.triangle[orient][0].x,
+				wp->shape.triangle[orient][0].y);
+		else {
 			if (bitmap >= KINDBITMAPS || !alive)
 				XFillPolygon(display, window, gc,
-					     wp->shape.triangle[orient], 3, Convex, CoordModePrevious);
+					wp->shape.triangle[orient], 3,
+					Convex, CoordModePrevious);
 			else {
 				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 				XFillPolygon(display, window, gc,
-					     wp->shape.triangle[orient], 3, Convex, CoordModePrevious);
+					wp->shape.triangle[orient], 3,
+					Convex, CoordModePrevious);
 				XSetForeground(display, gc, colour);
+				if (wp->vertical) {
+					wp->shape.triangle[orient][0].x += -4 * wp->xs / 5 +
+                                        	((orient) ? wp->xs / 3 : 3 * wp->xs / 5);
+                                        wp->shape.triangle[orient][0].y += -wp->ys / 2 + 1;
+					ix = ((orient) ? -wp->xs / 2 : wp->xs / 2);
+				} else {
+					wp->shape.triangle[orient][0].y += -4 * wp->xs / 5 +
+                                        	((orient) ? wp->xs / 3 : 3 * wp->xs / 5);
+                                        wp->shape.triangle[orient][0].x += -wp->ys / 2 + 1;
+					iy = ((orient) ? -wp->xs / 2 : wp->xs / 2);
+				}
 				XFillArc(display, window, gc,
-				     wp->xb + wp->xs * col - 4 * wp->xs / 5 +
-				    ((orient) ? wp->xs / 3 : 3 * wp->xs / 5),
-					 wp->yb + wp->ys * row - wp->ys / 2 + 1, wp->ys - 3, wp->ys - 3,
-					 0, 23040);
+					wp->shape.triangle[orient][0].x + ix,
+					wp->shape.triangle[orient][0].y + iy,
+					wp->ys - 3, wp->ys - 3,
+					0, 23040);
 			}
 		}
 	}
@@ -343,7 +413,7 @@ removefrom_kindlist(watorstruct * wp, CellList * ptr)
 	ptr->previous->next = ptr->next;
 	ptr->next->previous = ptr->previous;
 	wp->arr[ptr->info.col + ptr->info.row * wp->ncols] = 0;
-	(void) free((void *) ptr);
+	free(ptr);
 }
 
 static Bool
@@ -400,7 +470,7 @@ flush_kindlist(watorstruct * wp, int kind)
 		wp->currkind->previous->next = wp->lastkind[kind];
 		wp->lastkind[kind]->previous = wp->currkind->previous;
 		/* wp->arr[wp->currkind->info.col + wp->currkind->info.row * wp->ncols] = 0; */
-		(void) free((void *) wp->currkind);
+		free(wp->currkind);
 	}
 }
 
@@ -632,16 +702,16 @@ free_wator(watorstruct *wp)
 	for (kind = 0; kind <= KINDS; kind++) {
 		if (wp->firstkind[kind] != NULL) {
 			flush_kindlist(wp, kind);
-			(void) free((void *) wp->firstkind[kind]);
+			free(wp->firstkind[kind]);
 			wp->firstkind[kind] = (struct _CellList *) NULL;
 		}
 		if (wp->lastkind[kind] != NULL) {
-			(void) free((void *) wp->lastkind[kind]);
+			free(wp->lastkind[kind]);
 			wp->lastkind[kind] = (struct _CellList *) NULL;
 		}
 	}
 	if (wp->arr != NULL) {
-		(void) free((void *) wp->arr);
+		free(wp->arr);
 		wp->arr = (CellList **) NULL;
 	}
 }
@@ -680,7 +750,11 @@ init_wator(ModeInfo * mi)
 	} else			/* Exterminate all  */
 		for (i = FISH; i <= KINDS; i++)
 			flush_kindlist(wp, i);
-
+	if (MI_IS_FULLRANDOM(mi)) {
+		wp->vertical = (Bool) (LRAND() & 1);
+	} else {
+		wp->vertical = vertical;
+        }
 	wp->width = MI_WIDTH(mi);
 	wp->height = MI_HEIGHT(mi);
 	if (wp->width < 2)
@@ -705,8 +779,12 @@ init_wator(ModeInfo * mi)
 	}
 
 	if (wp->neighbors == 6) {
-		int         nccols, ncrows, sides;
+		int nccols, ncrows, sides;
 
+		if (!wp->vertical) {
+			wp->height = MI_WIDTH(mi);
+			wp->width = MI_HEIGHT(mi);
+		}
 		if (wp->width < 8)
 			wp->width = 8;
 		if (wp->height < 8)
@@ -729,11 +807,22 @@ init_wator(ModeInfo * mi)
 		wp->ncols = nccols / 2;
 		wp->nrows = 2 * (ncrows / 4);
 		wp->xb = (wp->width - wp->xs * nccols) / 2 + wp->xs / 2;
-		wp->yb = (wp->height - wp->ys * (ncrows / 2) * 2) / 2 + wp->ys - 2;
+		wp->yb = (wp->height - wp->ys * (ncrows / 2) * 2) / 2 +
+			wp->ys / 3;
 		for (sides = 0; sides < 6; sides++) {
-			wp->shape.hexagon[sides].x = (wp->xs - 1) * hexagonUnit[sides].x;
-			wp->shape.hexagon[sides].y =
-				((wp->ys - 1) * hexagonUnit[sides].y / 2) * 4 / 3;
+			if (wp->vertical) {
+				wp->shape.hexagon[sides].x =
+					(wp->xs - 1) * hexagonUnit[sides].x;
+				wp->shape.hexagon[sides].y =
+					((wp->ys - 1) * hexagonUnit[sides].y /
+					2) * 4 / 3;
+			} else {
+				wp->shape.hexagon[sides].y =
+					(wp->xs - 1) * hexagonUnit[sides].x;
+				wp->shape.hexagon[sides].x =
+					((wp->ys - 1) * hexagonUnit[sides].y /
+					2) * 4 / 3;
+			}
 		}
 	} else if (wp->neighbors == 4 || wp->neighbors == 8) {
 		if (wp->width < 2)
@@ -769,8 +858,12 @@ init_wator(ModeInfo * mi)
 		wp->xb = (wp->width - wp->xs * wp->ncols) / 2;
 		wp->yb = (wp->height - wp->ys * wp->nrows) / 2;
 	} else {		/* TRI */
-		int         orient, sides;
+		int orient, sides;
 
+		if (!wp->vertical) {
+			wp->height = MI_WIDTH(mi);
+			wp->width = MI_HEIGHT(mi);
+		}
 		if (wp->width < 2)
 			wp->width = 2;
 		if (wp->height < 2)
@@ -794,10 +887,17 @@ init_wator(ModeInfo * mi)
 		wp->yb = (wp->height - wp->ys * wp->nrows) / 2 + wp->ys / 2;
 		for (orient = 0; orient < 2; orient++) {
 			for (sides = 0; sides < 3; sides++) {
-				wp->shape.triangle[orient][sides].x =
-					(wp->xs - 2) * triangleUnit[orient][sides].x;
-				wp->shape.triangle[orient][sides].y =
-					(wp->ys - 2) * triangleUnit[orient][sides].y;
+				if (wp->vertical) {
+					wp->shape.triangle[orient][sides].x =
+						(wp->xs - 2) * triangleUnit[orient][sides].x;
+					wp->shape.triangle[orient][sides].y =
+						(wp->ys - 2) * triangleUnit[orient][sides].y;
+				} else {
+					wp->shape.triangle[orient][sides].y =
+						(wp->xs - 2) * triangleUnit[orient][sides].x;
+					wp->shape.triangle[orient][sides].x =
+						(wp->ys - 2) * triangleUnit[orient][sides].y;
+				}
 			}
 		}
 	}
@@ -805,7 +905,7 @@ init_wator(ModeInfo * mi)
 	wp->positions = wp->ncols * wp->nrows;
 
 	if (wp->arr != NULL)
-		(void) free((void *) wp->arr);
+		free(wp->arr);
 	if ((wp->arr = (CellList **) calloc(wp->positions,
 			sizeof (CellList *))) == NULL) {
 		free_wator(wp);
@@ -1022,7 +1122,7 @@ release_wator(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_wator(&wators[screen]);
-		(void) free((void *) wators);
+		free(wators);
 		wators = (watorstruct *) NULL;
 	}
 }
