@@ -233,11 +233,13 @@ fixColormap(ModeInfo * mi, int ncolors, float saturation,
 	MI_BLACK_PIXEL(mi) = BlackPixelOfScreen(scr);
 	MI_WHITE_PIXEL(mi) = WhitePixelOfScreen(scr);
 #else
-	MI_BLACK_PIXEL(mi) = allocPixel(display, cmap, "Black", "Black");
-	MI_WHITE_PIXEL(mi) = allocPixel(display, cmap, "White", "White");
+	MI_BLACK_PIXEL(mi) = allocPixel(display, cmap, (char *) "Black", (char
+*) "Black");
+	MI_WHITE_PIXEL(mi) = allocPixel(display, cmap, (char *) "White", (char
+*) "White");
 #endif
-	MI_BG_PIXEL(mi) = allocPixel(display, cmap, background, "White");
-	MI_FG_PIXEL(mi) = allocPixel(display, cmap, foreground, "Black");
+	MI_BG_PIXEL(mi) = allocPixel(display, cmap, background, (char *) "White");
+	MI_FG_PIXEL(mi) = allocPixel(display, cmap, foreground, (char *) "Black");
 	hsbramp(0.0, saturation, 1.0, 1.0, saturation, 1.0, colorcount,
 		red, green, blue);
 
