@@ -414,7 +414,7 @@ getRandomFile(char *randomfile, char *randomfile_local)
 #endif
 
 extern int  XbmReadFileToImage(char *filename,
-			       int *width, int *height, unsigned char **bits);
+			       int *width, int *height, char **bits);
 
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
@@ -564,8 +564,8 @@ getImage(ModeInfo * mi, XImage ** logo,
 		if (*graphics_format <= 0) {
 			if (!blogo.data) {
 				if (BitmapSuccess == XbmReadFileToImage(bitmap_local,
-						 &blogo.width, &blogo.height,
-					   (unsigned char **) &blogo.data)) {
+						&blogo.width, &blogo.height,
+						&blogo.data)) {
 					blogo.bytes_per_line = (blogo.width + 7) / 8;
 					*graphics_format = IS_XBMFILE;
 					*logo = &blogo;
