@@ -667,27 +667,29 @@ getUserName(void)
 
 #define CPASSLENGTH 14
 #define CPASSCHARS 64
-static void
+static Bool
 gpasskey(char *pass)
 {
 	static char saltchars[CPASSCHARS + 1] =
 	"abcdefghijklmnopwrstuvwxyzABCDEFGHIJKLMNOPWRSTUVWXYZ1234567890./";
-	char        *pw, *pw2, salt[3];
+	char        *pw, salt[3], key[9];
 #if 0
 	char       *getpass(const char *);
 #endif
-
 	pw = (char *) getpass("  Key: ");
-	pw2 = (char *) getpass("Again: ");
-	if (strncmp(pw, pw2, 8) != 0) {
+	(void) strncpy(key, pw, 8);
+	pw = (char *) getpass("Again: ");
+	if (strncmp(pw, key, 8) != 0) {
 		(void) fprintf(stderr, "%s: Mismatch, try again\n", ProgramName);
-		exit(1);
+		return False;
 	}
+	(void) strncpy(key, "********", 8);
 	/* grab a random printable character that is not a colon */
 	salt[0] = saltchars[LRAND() & (CPASSCHARS - 1)];
 	salt[1] = saltchars[LRAND() & (CPASSCHARS - 1)];
 	salt[2] = '\0';
 	(void) strncpy(pass, (char *) crypt(pw, salt), CPASSLENGTH);
+	return True;
 }
 
 static void
@@ -723,7 +725,10 @@ gpass(void)
 #if defined(HAVE_KRB4) || defined(HAVE_KRB5)
 			(void) strcpy(userpass, "*");
 #else
-			gpasskey(userpass);
+			if (!gpasskey(userpass)) {
+				remove(xlockrc); /* else creates annoying null file */
+				exit(1);
+			}
 #endif /* KRB4 || KRB5 */
 			if (fp)
 				(void) fprintf(fp, "%s\n", userpass);
@@ -742,7 +747,10 @@ gpass(void)
 				(void) fprintf(stderr, "%s: %s crypted password %s\n", xlockrc,
 				       buf[0] == '\0' ? "null" : "bad", buf);
 #if defined(HAVE_KRB4) || defined(HAVE_KRB5)
-				gpasskey(buf);
+				if (!gpasskey(buf)) {
+					remove(xlockrc); /* else creates annoying null file */
+					exit(1);
+				}
 #else
 				exit(1);
 #endif
@@ -1406,7 +1414,7 @@ checkPasswd(char *buffer)
 #endif
 	) {
 		done = True;
-		if (!(rootpass && *buffer))
+		if (!(rootpass != NULL && *buffer))
 			/*
 			 * root has no password, don't let him in...
 			 */
