@@ -1114,7 +1114,7 @@ Help(void)
 static void
 Version(void)
 {
-	(void) printf("XLock version %s\n", VERSION);
+	(void) printf("XLock version xlockmore-%s\n", VERSION);
 	exit(0);
 }
 
@@ -1467,8 +1467,6 @@ descr(char *name)
 static void
 openDisplay(Display ** displayp)
 {
-	char       *buf;
-
 /* PURIFY 4.0.1 on Solaris 2 reports an uninitialized memory read on the next
  * the following line. */
 	if (!(*displayp = XOpenDisplay((displayname) ? displayname : ""))) {
@@ -1512,7 +1510,6 @@ static void
 checkDisplay(void)
 {
 #ifndef WIN32
-	char       *buf;
 	struct hostent *host;
 
 	/*
