@@ -17,6 +17,7 @@ static const char sccsid[] = "@(#)vis.c	4.07 97/01/30 xlockmore";
 
 #include "xlock.h"
 #include "vis.h"
+#include "visgl.h"
 
 extern Bool verbose;
 extern Bool debug;
@@ -186,12 +187,14 @@ defaultVisualInfo(Display * display, int screen)
 {
 	XVisualInfo *info_list = (XVisualInfo *) NULL,
 		*info = (XVisualInfo *) NULL, vTemplate;
-	int         n = 0;
 
 	vTemplate.screen = screen;
 	vTemplate.depth = DisplayPlanes(display, screen);
+#ifndef WIN32
 	{
-#if defined( USE_GL )		/* go with what init_GL found */
+		int         n = 0;
+#if defined( USE_GL )	/* go with what init_GL found */
+
 		XVisualInfo *wantVis = (XVisualInfo *) NULL;
 
 		if (!glOK) {
@@ -287,6 +290,7 @@ defaultVisualInfo(Display * display, int screen)
 		}
 #endif
 	}
+#endif
 	if (verbose) {
 		showVisualInfo(info);
 	}
