@@ -22,6 +22,79 @@ static const char sccsid[] = "@(#)visgl.c	5.24 2007/01/18 xlockmore";
 #include "visgl.h"
 
 #ifdef USE_GL
+#ifdef WIN32
+HGLRC
+init_GL(ModeInfo *mi)
+{
+	PIXELFORMATDESCRIPTOR pfd;
+	int pixelFormat;
+#if 1
+	BYTE type = PFD_TYPE_RGBA;
+#else
+	BYTE type = PFD_TYPE_COLORINDEX;
+#endif
+	DWORD flags = PFD_DOUBLEBUFFER;
+	HGLRC context;
+
+	memset(&pfd, 0, sizeof(PIXELFORMATDESCRIPTOR));
+	pfd.nSize = sizeof(PIXELFORMATDESCRIPTOR);
+	pfd.nVersion = 1;
+	pfd.dwFlags = PFD_DRAW_TO_WINDOW | PFD_SUPPORT_OPENGL | flags;
+	pfd.dwLayerMask = PFD_MAIN_PLANE;
+	/*pfd.cColorBits = 8;
+	pfd.cDepthBits = 16;*/
+	pfd.iPixelType = type;
+	pfd.cColorBits = 24;
+	pfd.cDepthBits = 32;
+	if ((pixelFormat = ChoosePixelFormat(hdc, &pfd)) == 0) {
+		DWORD err;
+		char buf1[80];
+
+		err = GetLastError();
+		/* 6 ERROR_INVALID_HANDLE */
+#if DEBUG
+		(void) sprintf(buf1, "%s: %d\n", "ChoosePixelFormat failed", err);
+		OutputDebugString(buf1);
+#endif
+		free(buf1);
+		return NULL;
+	}
+
+	if (SetPixelFormat(hdc, pixelFormat, &pfd) == FALSE) {
+#if DEBUG
+		OutputDebugString("SetPixelFormat failed");
+#endif
+		MessageBox(NULL, "SetPixelFormat failed", "Error", MB_OK);
+		return NULL;
+	}
+	DescribePixelFormat(hdc, pixelFormat,
+		sizeof(PIXELFORMATDESCRIPTOR), &pfd);
+	{
+		GLboolean rgbaMode;
+		glGetBooleanv(GL_RGBA_MODE, &rgbaMode);
+		if (!rgbaMode)
+			glClearIndex(0.0);
+	}
+	context = wglCreateContext(hdc);
+	wglMakeCurrent(hdc, context);
+	return context;
+}
+
+/*void
+glXMakeCurrent(Display *display, Window window, HGLRC hglrc)
+{
+	wglMakeCurent(hdc, hglrc);
+}*/
+
+void
+FreeAllGL(ModeInfo * mi)
+{
+}
+void
+do_fps (ModeInfo *mi)
+{
+}
+#else
 #include <GL/glu.h>
 
 static GLXContext *glXContext = (GLXContext *) NULL;
@@ -484,3 +557,4 @@ do_fps (ModeInfo *mi)
     (void) fps_print_string (mi, (float) fps_text_x, (float) -fps_text_y, msg);
 }
 #endif
+#endif
